@@ -743,9 +743,54 @@ def fromEntries(*args, object=True):
 
     return obj
 
+def array_split(arr, index):
+    if isinstance(index, int):
+        return arr[:index], arr[index:]
+    
+    if isinstance(index, slice):
+        start, stop, step = index.start, index.stop, index.step
+        if step is None:
+            step = 1
+
+        if step > 0:
+            if start is None:
+                start = 0
+            elif start < 0:
+                start += len(arr)
+
+            if stop is None:
+                stop = len(arr)
+            elif stop < 0:
+                stop += len(arr)
+
+            if step > 1:
+                rest = (arr[i] for i in {*range(start, stop)} - {*range(start, stop, step)})
+                rest = arr[:start] + type(arr)(rest) + arr[stop:]
+            else:
+                rest = arr[:start] + arr[stop:]
+        else:
+            if start is None:
+                start = len(arr) - 1
+            elif start < 0:
+                start += len(arr)
+
+            if stop is None:
+                stop = -1
+            elif stop < -1:
+                stop += len(arr)
+            
+            if step < -1:
+                rest = (arr[i] for i in {*range(start, stop, -1)} - {*range(start, stop, step)})
+                rest = arr[:stop + 1] + type(arr)(rest) + arr[start + 1:]
+            else:
+                rest = arr[:stop + 1] + arr[start + 1:]
+
+        return arr[index], rest
+
 
 if __name__ == '__main__':
-    obj = Object(a=1, b=2, c=3)
-    dic = {**obj}
-    print(dic)
+    arr = [*range(10)]
+    former, latter = array_split(arr, slice(-2, -8, -2))
+    print(former)
+    print(latter)
     
